/**
 * @license
 * Copyright 2023 Google LLC
 * SPDX-License-Identifier: Apache-2.0
 */
import '../../elevation/elevation.js';
import '../../focus/md-focus-ring.js';
import '../../ripple/ripple.js';
import { LitElement } from 'lit';
/**
 * Symbol for tabs to use to animate their indicators based off another tab's
 * indicator.
 */
declare const INDICATOR: unique symbol;
/**
 * Symbol used by the tab bar to request a tab to animate its indicator from a
 * previously selected tab.
 */
export declare const ANIMATE_INDICATOR: unique symbol;
/**
 * Tab component.
 */
export declare class Tab extends LitElement {
    /**
     * Whether or not the tab is selected.
     **/
    active: boolean;
    /**
     * TODO(b/293476210): remove after migrating
     * @deprecated use `active`
     */
    get selected(): boolean;
    set selected(active: boolean);
    /**
     * In SSR, set this to true when an icon is present.
     */
    hasIcon: boolean;
    /**
     * In SSR, set this to true when there is no label and only an icon.
     */
    iconOnly: boolean;
    readonly [INDICATOR]: HTMLElement | null;
    protected fullWidthIndicator: boolean;
    private readonly assignedDefaultNodes;
    private readonly assignedIcons;
    private readonly internals;
    constructor();
    protected render(): import("lit-html").TemplateResult<1>;
    protected getContentClasses(): {
        'has-icon': boolean;
        'has-label': boolean;
    };
    protected updated(): void;
    private handleKeydown;
    private handleContentClick;
    [ANIMATE_INDICATOR](previousTab: Tab): void;
    private getKeyframes;
    private handleSlotChange;
    private handleIconSlotChange;
}
export {};
